@@ -243,18 +243,27 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
  } 
  
    
- s u b   r e s o l v e _ q u e r y   { 
-         m y   ( $ s e l f ,   $ q u e r y )   =   @ _ ; 
- 
-         m y   $ s y s _ q u e r y   =   $ s e l f - > r e s o l v e _ s y s _ q u e r y ( $ q u e r y ) ; 
- 
-         r e t u r n   $ s y s _ q u e r y   i f   d e f i n e d   $ s y s _ q u e r y ; 
- 
- #         i f   ( $ q u e r y   e q   ' s e l e c t   @ @ v e r s i o n _ c o m m e n t   l i m i t   1 ' )   { 
- #                 r e t u r n   ' t e s t ' ; 
- #         } 
-         r e t u r n   ' t e s t _ t a b l e s ' ; 
- } 
+ # s u b   r e s o l v e _ q u e r y   { 
+ #         m y   ( $ s e l f ,   $ q u e r y )   =   @ _ ; 
+ # 
+ #         $ s e l f - > S U P E R : : r e s o l v e _ q u e r y ( @ _ ) ; 
+ # 
+ #         m y   $ s y s _ q u e r y   =   $ s e l f - > r e s o l v e _ s y s _ q u e r y ( $ q u e r y ) ; 
+ # 
+ #         p r i n t   "   r e f   " . r e f ( $ s e l f ) . "   \ n " ; 
+ # 
+ # 
+ #         p r i n t   D u m p e r ( \ @ I S A ) ; 
+ #         r e t u r n   $ s y s _ q u e r y   i f   d e f i n e d   $ s y s _ q u e r y ; 
+ # 
+ #         p r i n t   " p a r e n t   r e s o l v e   q u e r y   \ n " ; 
+ # 
+ # 
+ # #         i f   ( $ q u e r y   e q   ' s e l e c t   @ @ v e r s i o n _ c o m m e n t   l i m i t   1 ' )   { 
+ # #                 r e t u r n   ' t e s t ' ; 
+ # #         } 
+ #         r e t u r n   ' t e s t _ t a b l e s ' ; 
+ # } 
  
  
  s u b   r e s o l v e _ s y s _ q u e r y   { 
@@ -269,6 +278,9 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
          e l s i f   ( $ q u e r y   = ~   / d a t a b a s e s / )   { 
                  r e t u r n   ' t e s t _ d b ' ; 
          } 
+         e l s i f   ( $ q u e r y   = ~   / ^ s e l e c t   d a t a b a s e / i )   { 
+                 r e t u r n   ' s e l e c t _ d b ' ; 
+         } 
          e l s i f   ( $ q u e r y   = ~   / ^ u s e /   o r   $ q u e r y   = ~   / ^ t e s t _ c h a n g e _ d b / i   o r   $ q u e r y   = ~   / ^ s e l e c t   d a t a b a s e / i )   { 
                  r e t u r n   ' c h a n g e _ d b ' ; 
          } 
@@ -305,6 +317,9 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
  
          } 
  
+ u s e   D a t a : : D u m p e r ; 
+ p r i n t   D u m p e r ( \ @ I S A ) ; 
+ 
          r e t u r n   @ I S A ; 
  } 
  
@@ -327,13 +342,23 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
  #                 m y   $ c o m m a n d       =   u n p a c k ( ' C ' ,   s u b s t r ( $ h e a d e r _ f l a g s ,   3 ,   1 ) ) ; 
  #                 m y   $ d a t a _             =   l e n g t h ( $ d a t a )   >   3   ?   s u b s t r ( $ d a t a ,   3 )   :   u n d e f ; 
  
- #                 m y   $ e v e n t   =   $ s e l f - > r e s o l v e _ q u e r y ( $ d a t a ) ; 
+                 m y   $ e v e n t ; 
  
- #                 p r i n t   " f i r i n g   $ e v e n t   q u e r y   i s   $ d a t a   \ n " ; 
-                 
+                 e v a l   { 
+                         $ e v e n t   =   $ s e l f - > r e s o l v e _ q u e r y ( $ d a t a ) ; 
+                 } ; 
+ 
+                 i f   ( $ @ )   { 
+                         $ e v e n t   =   $ s e l f - > r e s o l v e _ s y s _ q u e r y ( $ d a t a ) ; 
+                 } 
+ 
+                 p r i n t   " f i r i n g   q u e r y   i s   $ d a t a   \ n " ; 
+               
+             
+   
                  P O E : : K e r n e l - > p o s t ( 
                          $ s e l f - > s e s s i o n _ i d ,   
-                         $ s e l f - > r e s o l v e _ q u e r y ( $ d a t a ) ,   
+                         $ e v e n t ,   
                          $ d a t a 
                  ) ; 
        } 
@@ -605,7 +630,7 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
        
        	     p r i n t   " v e r s i o n _ c o m m e n t   ! !   \ n " ; 
        	 
-             $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' f i e l d '   ) ] , 
+             $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' T a b l e s _ i n _ t e s t d b '   ) ] , 
                          [ [ ' m y t a b l e _ ' . $ s e s s i o n - > I D , ' m y t a b l e _ ' . $ s e s s i o n - > I D , ' m y t a b l e _ ' . $ s e s s i o n - > I D ] ] ) ;       	 
  
              p r i n t   " d a   D B   w a s   s e n t   . . .   \ n " ; 
@@ -631,12 +656,12 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
                  $ c o d e - > ( $ m o d u l e ,   $ s e l f ,   $ d a t a ) ;   
          } 
  
- 
-                 P O E : : K e r n e l - > p o s t ( 
-                         $ s e l f - > s e s s i o n _ i d ,   
-                         ' a _ d u m m y _ q u e r y ' ,   
-                         $ d a t a 
-                 ) ; 
+ # 
+ #                 P O E : : K e r n e l - > p o s t ( 
+ #                         $ s e l f - > s e s s i o n _ i d ,   
+ #                         ' a _ d u m m y _ q u e r y ' ,   
+ #                         $ d a t a 
+ #                 ) ; 
  
          
  
@@ -646,6 +671,36 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
  
  } 
  
+ s u b   s e l e c t _ d b   { 
+         m y   (   $ k e r n e l ,   $ s e s s i o n ,   $ h e a p ,   $ s e l f   )   =   @ _ [   K E R N E L ,   S E S S I O N ,   H E A P ,   O B J E C T ] ; 
+         m y   $ d a t a   =   $ _ [ A R G 0 ] ; 
+ 
+         p r i n t   ' t e s t   ~   s e s s i o n   I D   =   ' . $ s e s s i o n - > I D . " \ n " ; 
+       
+ 
+         #   
+         #   m o d u l e   l o a d   a n d   s h i t   . . . 
+         # 
+         m y   $ m o d u l e   =   $ s e l f - > s e r v e r _ c l a s s ; 
+ #         p r i n t   ( $ p a c k a g e . " - > c h a n g e _ d b ( " . $ d a t a . " ) " ) ; 
+ 
+         u n l e s s   ( C l a s s : : I n s p e c t o r - > l o a d e d ( $ m o d u l e ) )   { 
+                 r e q u i r e   C l a s s : : I n s p e c t o r - > f i l e n a m e ( $ m o d u l e ) ; 
+         } 
+ 
+         i f   ( m y   $ c o d e   =   $ m o d u l e - > c a n ( ' c h a n g e _ d b ' ) )   { 
+                 $ c o d e - > ( $ m o d u l e ,   $ s e l f ,   $ d a t a ) ;   
+         } 
+ 
+       	     p r i n t   " s e l e c t   D B   \ n " ; 
+       	 
+             $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' D a t a b a s e '   ) ] , 
+                 [ [ ' t e s t d b ' ] ] ) ;   	 
+ 
+             p r i n t   " d a   D B   w a s   s e n t   . . .   \ n " ; 
+ 
+ 
+ } 
  s u b   t e s t _ d b   { 
          m y   (   $ k e r n e l ,   $ s e s s i o n ,   $ h e a p ,   $ s e l f   )   =   @ _ [   K E R N E L ,   S E S S I O N ,   H E A P ,   O B J E C T ] ; 
          m y   $ d a t a   =   $ _ [ A R G 0 ] ; 
@@ -654,8 +709,8 @@ p a c k a g e   P O E : : C o m p o n e n t : : D B I x : : M y S e r v e r : : 
        
        	     p r i n t   " v e r s i o n _ c o m m e n t   ! !   \ n " ; 
        	 
-             $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' f i e l d '   ) , n e w _ d e f i n i t i o n (   n a m e   = >   ' f i e l d 2 '   ) ] , 
-                 [ [ ' m y d b ' , ' t e s t 2 ' ] , [ ' t e s t d b ' , ' t e s t 2 ' ] ] ) ;   	 
+             $ s e l f - > s e n d _ r e s u l t s ( [ n e w _ d e f i n i t i o n (   n a m e   = >   ' D a t a b a s e '   ) ] , 
+                 [ [ ' m y d b ' ] , [ ' t e s t d b ' ] ] ) ;   	 
  
              p r i n t   " d a   D B   w a s   s e n t   . . .   \ n " ; 
  
